==> suir-component-mapper-3.12.0.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import validTextFields from '@data-driven-forms/common/utils/valid-text-fields';

var PlainText = function PlainText(_ref) {
  var variant = _ref.variant,
      label = _ref.label,
      name = _ref.name,
      rest = _objectWithoutProperties(_ref, ["variant", "label", "name"]);

  return typeof label === 'string' ? label.split('\n').map(function (paragraph, index) {
    return React.createElement(variant, _objectSpread({
      key: "".concat(name, "-").concat(index)
    }, rest), paragraph);
  }) : {
    label: label
  };
};

PlainText.propTypes = {
  variant: PropTypes.oneOf(validTextFields),
  label: PropTypes.node.isRequired,
  name: PropTypes.string.isRequired
};
PlainText.defaultProps = {
  variant: 'p'
};
export default PlainText;

==> suir-component-mapper-3.15.0.tgz: package/esm/plain-text/plain-text.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["variant", "label", "name"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import validTextFields from '@data-driven-forms/common/utils/valid-text-fields';

var PlainText = function PlainText(_ref) {
  var variant = _ref.variant,
      label = _ref.label,
      name = _ref.name,
      rest = _objectWithoutProperties(_ref, _excluded);

  return typeof label === 'string' ? label.split('\n').map(function (paragraph, index) {
    return /*#__PURE__*/React.createElement(variant, _objectSpread({
      key: "".concat(name, "-").concat(index)
    }, rest), paragraph);
  }) : {
    label: label
  };
};

PlainText.propTypes = {
  variant: PropTypes.oneOf(validTextFields),
  label: PropTypes.node.isRequired,
  name: PropTypes.string.isRequired
};
PlainText.defaultProps = {
  variant: 'p'
};
export default PlainText;
